aboutsummaryrefslogtreecommitdiffstats
path: root/xen/include/xen/event.h
diff options
context:
space:
mode:
authorKeir Fraser <keir.fraser@citrix.com>2008-07-04 12:39:18 +0100
committerKeir Fraser <keir.fraser@citrix.com>2008-07-04 12:39:18 +0100
commit52d9d32d02078742805861e7152c45b03209ebab (patch)
tree336ff7656ef06cbf4f2ce569093a010973e59bb6 /xen/include/xen/event.h
parentddfd61bd7e71b4ad602da69473586d072017992b (diff)
downloadxen-52d9d32d02078742805861e7152c45b03209ebab.tar.gz
xen-52d9d32d02078742805861e7152c45b03209ebab.tar.bz2
xen-52d9d32d02078742805861e7152c45b03209ebab.zip
Cleanups to suspend-event-channel patches.
Signed-off-by: Keir Fraser <keir.fraser@citrix.com>
Diffstat (limited to 'xen/include/xen/event.h')
-rw-r--r--xen/include/xen/event.h7
1 files changed, 2 insertions, 5 deletions
diff --git a/xen/include/xen/event.h b/xen/include/xen/event.h
index fadf01b7ec..67b83c50a6 100644
--- a/xen/include/xen/event.h
+++ b/xen/include/xen/event.h
@@ -16,9 +16,6 @@
#include <asm/bitops.h>
#include <asm/event.h>
-/* Returns TRUE if the delivery port was already pending. */
-int evtchn_set_pending(struct vcpu *v, int port);
-
/*
* send_guest_vcpu_virq: Notify guest via a per-VCPU VIRQ.
* @v: VCPU to which virtual IRQ should be sent
@@ -41,8 +38,8 @@ void send_guest_global_virq(struct domain *d, int virq);
*/
int send_guest_pirq(struct domain *d, int pirq);
-/* Send a notification from a local event-channel port. */
-long evtchn_send(unsigned int lport);
+/* Send a notification from a given domain's event-channel port. */
+int evtchn_send(struct domain *d, unsigned int lport);
/* Bind a local event-channel port to the specified VCPU. */
long evtchn_bind_vcpu(unsigned int port, unsigned int vcpu_id);